@@ -4,7 +4,7 @@ import unittest
 import doctest
 import django
 
-BASE_PATH = os.path.dirname(__file__) + 'jsonfield/'
+BASE_PATH = os.path.dirname(__file__)
 
 def main(db_engine='sqlite3'):
     """
@@ -32,6 +32,12 @@ def main(db_engine='sqlite3'):
     global_settings.STATIC_ROOT = global_settings.MEDIA_ROOT
     
     global_settings.SECRET_KEY = '334ebe58-a77d-4321-9d01-a7d2cb8d3eea'
+    if os.environ.get('COVERAGE', None):
+        global_settings.TEST_RUNNER = 'django_coverage.coverage_runner.CoverageRunner'
+    global_settings.COVERAGE_REPORT_HTML_OUTPUT_DIR =os.path.join(BASE_PATH, '.coverage')
+    global_settings.COVERAGE_USE_STDOUT = True
+    global_settings.COVERAGE_PATH_EXCLUDES = ['.hg', 'templates', 'tests', 'sql', '__pycache__']
+    
     
     from django.test.utils import get_runner
     test_runner = get_runner(global_settings)
